//
// ========================================================================
// Copyright (c) Mort Bay Consulting Pty Ltd and others.
//
// This program and the accompanying materials are made available under the
// terms of the Eclipse Public License v. 2.0 which is available at
// https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
// which is available at https://www.apache.org/licenses/LICENSE-2.0.
//
// SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
// ========================================================================
//

package org.eclipse.jetty.demo;

import org.eclipse.jetty.server.Server;
import org.eclipse.jetty.server.ServerConnector;
import org.eclipse.jetty.servlet.ServletContextHandler;
import org.eclipse.jetty.websocket.jakarta.server.config.JakartaWebSocketServletContainerInitializer;

public class TestServerJetty11 {
	public static void main(String[] args) throws Exception {
		var server = new Server();
		var connector = new ServerConnector(server);
		connector.setPort(8011);
		server.addConnector(connector);

		ServletContextHandler context = new ServletContextHandler(null, "/", ServletContextHandler.SESSIONS);
		server.setHandler(context);

		JakartaWebSocketServletContainerInitializer.configure(context, (servletContext, wsContainer) -> {
			wsContainer.setDefaultMaxTextMessageBufferSize(65535);
			wsContainer.addEndpoint(TestSocketJetty11.class);
		});

		server.start();
		server.join();
	}
}
