//
// ========================================================================
// Copyright (c) Mort Bay Consulting Pty Ltd and others.
//
// This program and the accompanying materials are made available under the
// terms of the Eclipse Public License v. 2.0 which is available at
// https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
// which is available at https://www.apache.org/licenses/LICENSE-2.0.
//
// SPDX-License-Identifier: EPL-2.0 OR Apache-2.0
// ========================================================================
//

package org.eclipse.jetty.demo;

import jakarta.websocket.*;
import jakarta.websocket.server.ServerEndpoint;

import java.io.IOException;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

@ClientEndpoint
@ServerEndpoint(value = "/events/")
public class TestSocketJetty11 {

	@OnOpen
	public void onWebSocketConnect(Session session) {
		System.out.println("Socket Connected: " + session);
		Executors.newSingleThreadScheduledExecutor().schedule(() -> {
			System.out.println("outer...");
			session.getAsyncRemote().sendText("GOODBYE", sendResult -> {
				try {
					System.out.println("inner...");
					long startTime = System.currentTimeMillis();
					session.close();
					System.out.println("inner done. Took " + (System.currentTimeMillis() - startTime) + "ms.");
				} catch (IOException e) {
					throw new RuntimeException(e);
				}
			});
			System.out.println("outer done");
		}, 2, TimeUnit.SECONDS);
	}

	@OnClose
	public void onWebSocketClose(CloseReason reason) {
		System.out.println("Socket Closed: " + reason);
	}

	@OnError
	public void onWebSocketError(Throwable cause) {
		cause.printStackTrace(System.err);
	}

}
